#!/usr/bin/env python
# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai
from __future__ import (unicode_literals, division, absolute_import,
                        print_function)

__license__   = 'GPL v3'
__copyright__ = '2015, Terisa de Morgan <terisam@gmail.com>'
__docformat__ = 'restructuredtext en'

from calibre.ebooks.metadata.book.base import Metadata
from calibre.gui2 import error_dialog
from calibre.gui2.actions import InterfaceAction

from PyQt5.Qt import QMenu, QIcon, QPixmap
from calibre_plugins.norm_comment.html2text import html2text
from calibre_plugins.norm_comment.common_utils import set_plugin_icon_resources, get_icon

PLUGIN_ICONS = ['images/tools.png']

load_translations()

class NormCommentAction(InterfaceAction):

    name = 'Cleaning Comments'
    # Create our top-level menu/toolbar action (text, icon_path, tooltip, keyboard shortcut)
    action_spec = (_('Cleaning comments'), None, _('Clean html format in comments'), ())
    action_type = 'current'

    def genesis(self):
		# Read the plugin icons and store for potential sharing with the config widget
        icon_resources = self.load_resources(PLUGIN_ICONS)
        set_plugin_icon_resources(self.name, icon_resources)
        # Assign our menu to this action and an icon
        self.qaction.setIcon(get_icon(PLUGIN_ICONS[0]))
        self.qaction.triggered.connect(self._normalize_comment)

    def _normalize_comment(self):
        rows = self.gui.library_view.selectionModel().selectedRows()
        if not rows or len(rows) == 0:
            return error_dialog(self.gui, _('No selected book'),
                    _('No book selected for normalizing comments'), show=True)
        book_ids = self.gui.library_view.get_selected_ids()

        self._do_replace_text (book_ids)

    def _do_replace_text (self, book_ids):
        # Queue all the books and kick off the job
		
        dbA = self.gui.current_db

        db = self.gui.current_db.new_api

        # Para cada uno de los libros actualiza los metadatos

        id_aux = {}
		
		lis_aux_id = []

        for id in book_ids:
            miA = dbA.get_metadata (id, index_is_id=True, get_cover=False)
            texto = miA.get ("comments")
			
			if texto is not None:
				id_aux[id] = html2text(texto)
				lis_aux_id.append (id)

        dbA.new_api.set_field('comments', {id:id_aux[id] for id in lis_aux_id})
        self.gui.iactions['Edit Metadata'].refresh_gui(book_ids, covers_changed=False)